# ApiResourceReference

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**key** | [**ApiResourceKey**](ApiResourceKey.md) |  | [optional] 
**name** | **str** | The name of the resource that referred to. | [optional] 
**relationship** | [**ApiRelationship**](ApiRelationship.md) |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


